Crate tokio_with_wasm_proc

Crate tokio_with_wasm_proc 

Attribute Macros

main
Attribute macro that mimics tokio::main. This macro writes a function that simply spawns the given future inside the JavaScript environment. To execute the function, you might need to use #[wasm_bindgen(start)] in addition to this macro.